@@ -23,14 +23,14 @@ __copyright__ = "Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance
     "e" if sys.getfilesystemencoding() != "utf-8" else "\xe8"
 )
 __license__ = "GNU Lesser General Public License v3 or later (LGPLv3+)"
-__version__ = "0.7.2"
+__version__ = "0.7.4"
 
 from .api.errors import Error
 from .client.types import (
     Audio, Chat, ChatMember, ChatPhoto, Contact, Document, InputMediaPhoto,
     InputMediaVideo, InputPhoneContact, Location, Message, MessageEntity,
-    PhotoSize, Sticker, Update, User, UserProfilePhotos, Venue, Video,
-    VideoNote, Voice, CallbackQuery
+    PhotoSize, Sticker, Update, User, UserProfilePhotos, Venue, GIF, Video,
+    VideoNote, Voice, CallbackQuery, Messages
 )
 from .client.types.reply_markup import (
     ForceReply, InlineKeyboardButton, InlineKeyboardMarkup,
