@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from .chat_action import ChatAction
 from .client import Client
-from .parse_mode import ParseMode
-from .emoji import Emoji
+from .ext import BaseClient, ChatAction, Emoji, ParseMode
+from .filters import Filters
+from .handlers import MessageHandler, CallbackQueryHandler, RawUpdateHandler
